@@ -4,7 +4,7 @@ import base64
 import datetime
 import logging
 import threading
-from enum import Enum
+from enum import Enum, auto
 from logging import ERROR, LogRecord
 from typing import Any, Dict, List, Optional, cast
 from uuid import uuid4
@@ -53,6 +53,17 @@ class Confidence(Enum):
         return self.value
 
 
+class Module(Enum):
+    """Equivalent to the "Module" enum in the test_manifest.proto file."""
+
+    BESPOKE = auto()
+    SCHEMATHESIS = auto()
+    ZAPROXY = auto()
+
+    def __str__(self) -> str:
+        return self.name
+
+
 @attr.s(slots=True, repr=False)
 class AssertionResult:
     """Assertion result."""
@@ -512,13 +523,14 @@ class AfterTestSuiteExecutionPayload(Payload):
     thread_id: int = attr.ib(factory=threading.get_ident)
 
 
-@attr.s(slots=True)
+@attr.s(slots=True, kw_only=True)
 class BeforeTestExecutionPayload(Payload):
     test_case_id: str = attr.ib()
     name: str = attr.ib()
     method: str = attr.ib()
     path: str = attr.ib()
     relative_path: str = attr.ib()
+    categories: list[str] = attr.ib()
     test_suite_id: Optional[str] = attr.ib(default=None)
     description: Optional[str] = attr.ib(default=None)
 
